"""
when user type the command: python manageMongo.py makemigrations [app_name]:
    - generate a file from mongoModels.py into migrationMongo folder

when user type the command: python manageMongo.py migrate [app_name]:
    - connect to mongodb and execute files migrationMongo folder 
"""



import threading, queue
from multiprocessing import Process, Queue
import datetime

from pymongo import MongoClient
import copy
from bson.objectid import ObjectId

import copy


def create_connection_to_mongo(db_name, collection_name, url):
    client = MongoClient(url)
    local_func = locals()
    exec(f"connected = client.{db_name}.{collection_name}", globals(), local_func)
    connected = local_func["connected"]
    return connected


class MongoBaseModel:
    def __init__(self, **kwargs):
        # user must defind self.db_name, self.collection_name, self.url, self.fields
        # default self.create_thread = Process

        self.collection = create_connection_to_mongo(self.db_name, self.collection_name, self.url)

        self.data = copy.deepcopy(kwargs)
        self.create_thread = Process
        
        self.validate_data()

    def create(self, take_result=False):
        self.data['create_at'] = datetime.datetime.utcnow()

        if take_result:
            return self.collection.insert_one(self.data)
        else:
            self.create_thread(target=self.create_in_thread, args=(self.data,)).start()

    def create_in_thread(self, data):
        create_connection_to_mongo(self.db_name, self.collection_name, self.url).insert_one(data)

    def validate_data(self):
        for field in copy.deepcopy(self.data):
            if field not in self.fields:
                del self.data[field]




import pathlib
from setuptools import setup, find_packages

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

setup(
    name="django-connect-mongo",
    version="1.10.0",
    description="we use this package to work with mongodb easier",
    long_description=README,
    long_description_content_type="text/markdown",
    # url="",
    author="hieucao192",
    author_email="hieucaohd@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.9",
    ],
    packages=find_packages(),
    include_package_data=True,
    install_requires=["pymongo[srv]"],
)